cluster: Generate template for clustering, counting and plotting...

Description Usage Arguments

View source: R/setup.R

Description

Generate template for clustering, counting and plotting colors

Usage

1
cluster(from, to, shortname = paste0(from, "_", to))

Arguments

from

address, or latitude and longitude of the start of the route.

to

address, or latitude and longitude of the end of the route.

shortname

string suitable for use as directory name and in file names.


cwickham/routes documentation built on Nov. 4, 2019, 9:34 a.m.