Description Usage Arguments Details Value Examples
Coordinates of a route from two locations from the Google Directions API.
1 | get_route(from, to, api_key = maps_api_key(), ...)
|
from |
Character string for start of route: "The address, textual latitude/longitude value, or place ID from which you wish to calculate directions". |
to |
Character string for end of route |
api_key |
Character string of your API key. By default, looks for
|
... |
Other parameters passed to the Directions API |
The coordinates match instructions in the route and they will not be equispaced along the route.
tibble with lat, lon and order columns for each step in the
route.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.